function varargout = dsxy2figxy(varargin)

nOut = nargout;
error(nargoutchk(0, 2, nOut))

[ax,args,nIn] = axescheck(varargin{:});
error(nargchk(1, 2, nIn))

InOutStr = sprintf('%d%d', nIn, nOut);

switch InOutStr
    case '12'
        error('Position vector cannot translate to a pair of points')
    case {'10','11'}
        abox = args{1};
        assert(isvector(abox) && numel(abox)==4, ...
            'Position vector must be a 4-element vector')
    case {'20','21','22'}
        [x,y] = args{:};
        assert( isvector(x) && isvector(y) && numel(x)==numel(y), ...
            'X and Y coordinates must be vectors of the same size' )
        assert(nOut>1 || numel(x)==2, ...
            'Only a pair of points can translate to a position vector')
end

if isempty(ax)
    ax = gca;
end

axprop = get(ax, {'Units', 'XLim', 'YLim', ...
    'XDir', 'YDir', 'XScale', 'YScale'} );
[oldunits, axlim(1:2), axlim(3:4)] = axprop{1:3};

set(ax, 'Units', 'normalized');
axpos = get(ax, 'Position');
set(ax, 'Units', oldunits);

proptf = num2cell( ...
    strcmp( axprop(4:end), {'normal', 'normal', 'log', 'log'} ) );

[isxdirnormal, isydirnormal, isxxlog, isyylog] = proptf{:};

if isxxlog
    axlim(1:2) = log10(axlim(1:2));
    if exist('x', 'var')
        x = log10(x);
    else
        abox([1 3]) = log10(abox([1 3]));
    end
end

if isyylog
    axlim(3:4) = log10(axlim(3:4));
    if exist('x','var')
        y = log10(y);
    else
        abox([2 4]) = log10(abox([2 4]));
    end
end

axwidth = diff(axlim(1:2));
axheight = diff(axlim(3:4));

if any(strcmp(InOutStr, {'20','21'}))
    abox(1) = min(x);
    abox(2) = min(y);
    abox(3) = abs(x(2)-x(1));
    abox(4) = abs(y(2)-y(1));
end


if nOut>1
    
    if isxdirnormal
        dx = x - axlim(1);
    else
        dx = axlim(2) - x;
    end
    
    if isydirnormal
        dy = y - axlim(3);
    else
        dy = axlim(4) - y;
    end
    
    varargout{1} = dx*axpos(3)/axwidth + axpos(1);
    varargout{2} = dy*axpos(4)/axheight + axpos(2);
    
else
    
    if isxdirnormal
        dxpos = abox(1) - axlim(1);
    else
        dxpos = axlim(2) - abox(1);
    end
    
    if isydirnormal
        dypos = abox(2) - axlim(3);
    else
        dypos = axlim(4) - abox(2);
    end
    
    abox(1) = dxpos/axwidth*axpos(3) + axpos(1);
    abox(2) = dypos/axheight*axpos(4) + axpos(2);
    abox(3) = abox(3)*axpos(3)/axwidth;
    abox(4) = abox(4)*axpos(4)/axheight;
    varargout{1} = abox;
    
end
