clear all; clc; close all

% V = 1.66e-15 L;

% Set parameter values.
k = [1e-3 1e-4 0.1]; % /[nMsec sec sec]
xEtot = 200; % nM
% k = [2,1,1.5];
% xEtot = 4;

% Construct ODE
dxdt = @(t,x) [-(xEtot-x(2))*k(1), k(2);...
                (xEtot-x(2))*k(1),-(k(2)+k(3))]*x; % ODE


% Define initial conditions.
t0 = 0;
tf = 50; % sec
xStot = 500; % nM
% xStot = 8;
x0 = [xStot;0];
% Simulate the differential equation.
tf = tf*(1+eps);
[t,x] = ode15s(dxdt,[t0 tf],x0);

xS = x(:,1);
xE = xEtot-x(:,2);
xES = x(:,2);
xP = xStot-x(:,1)-x(:,2);

x = [xS xE xES xP];

% Try gtext command

% iS = find(xS>5.8, 1, 'last');
% iP = find(xP<4.5, 1, 'last');
% iE = find(xE<3, 1, 'last');
% iES = find(xES>1, 1, 'last');

prepfigure([8 6.3]);
prepaxes('box','on');
hTimeCourse = plot(t, x);
axis tight
% xlim([t0 tf])
% ylim([0 1.05*max(x(:))])
set(hTimeCourse, {'Color'}, {'r';'b';'k';'m'}, ...
                 {'LineWidth'},{1;1.2;1.2;1.2}, ...
                  {'LineStyle'},{'-';':';'--';'-.'} );
% htext(1) = text(t(iS),xS(iS),'\leftarrow S');
% htext(4) = text(t(iP),xP(iP),'\leftarrow P');
% htext(2) = text(t(iE),xE(iE),'\leftarrow E');
% htext(3) = text(t(iES),xES(iES),'\leftarrow ES');
htext(4:-1:1) = gtext({'$\mathrm{S}$';'$\mathrm{E}$';'$\mathrm{ES}$';'$\mathrm{P}$'});
set(htext, {'Color'}, {'r';'b';'k';'m'}, 'Interpreter', 'latex')

xlabel('time')
ylabel('concentration')
setfigure
printfigure('enzkin_ode')