clear all; clc; close all;

Mobj = sbiomodel('cell');

compObj = addcompartment(Mobj, 'contents');
Robj1 = addreaction(Mobj, 'E + S -> ES');
Kobj1 = addkineticlaw(Robj1,'MassAction');
Pobj1 = addparameter(Kobj1, 'k1', 1e-3);
set(Kobj1, 'ParameterVariableNames', 'k1');

Robj1r = addreaction(Mobj, 'ES -> E + S');
Kobj1r = addkineticlaw(Robj1r,'MassAction');
Pobj1r = addparameter(Kobj1r, 'k1r', 1e-4);
set(Kobj1r, 'ParameterVariableNames', 'k1r');

Robj2 = addreaction(Mobj, 'ES -> E + P');
Kobj2 = addkineticlaw(Robj2,'MassAction');
Pobj2 = addparameter(Kobj2, 'k2', 0.1);
set(Kobj2, 'ParameterVariableNames', 'k2');

Sobj1 = sbioselect('Type', 'species', 'Name', 'E');
set(Sobj1, 'InitialAmount', 20);
Sobj2 = sbioselect('Type', 'species', 'Name', 'S');
set(Sobj2, 'InitialAmount', 50);
Sobj3 = sbioselect('Type', 'species', 'Name', 'ES');
set(Sobj3, 'InitialAmount', 0);
Sobj4 = sbioselect('Type', 'species', 'Name', 'P');
set(Sobj4, 'InitialAmount', 0);

cs = getconfigset(Mobj);
set(cs, 'StopTime', 100);

[t_ode, x_ode] = sbiosimulate(Mobj, cs);
% x_ode = x_ode(:,[1 3]);

set(cs, 'SolverType', 'ssa');
% cs.SolverOptions.LogDecimation = 10;
cs.SolverOptions.RandomState = [];

[t_ssa, x_ssa] = sbiosimulate(Mobj, cs);
% x_ssa = x_ssa(:,[1 3]);

runs = 1e3;
cs.SolverOptions.RandomState = [];
simDataObj = sbioensemblerun(Mobj, runs);

[t_ensem,mu,var] = sbioensemblestats(simDataObj, {'S','ES'});
sd = sqrt(var);

newsimDataObj = resample(simDataObj, t_ensem(end), 'zoh');
[~, nncell] = selectbyname(newsimDataObj, 'ES');
x_endpoint(:,2) = [nncell{:}]';
clear nncell
[~, nncell] = selectbyname(newsimDataObj, 'S');
x_endpoint(:,1) = [nncell{:}]';

%%
save enzkin_stoch t_ensem mu sd x_endpoint

