function fixlegend(varargin)
%
%  Author: Mukhtar Ullah
%

[ax,args,nIn] = axescheck(varargin{:});

error(nargchk(0, 2, nIn))

if isempty(ax) || strcmp(get(ax, 'Tag'), 'legend')
    ax = gca;
end

hleg = legend(ax);

assert(~isempty(hleg), 'Missing legend (Empty plot)')

if nIn==0
    sfx = 0.1;
else
    sfx = 1 - args{1}; % supplied scaling factor
    validateattributes( sfx, ...
        {'numeric'}, {'scalar', 'real', 'positive', '<', 1} )
end

if nIn>1
    sfy = 1 - args{2}; % supplied scaling factor
    validateattributes( sfy, ...
        {'numeric'}, {'scalar', 'real', 'positive', '<', 1} )
end

hmarker = findobj(hleg, 'type', 'line', ...
    '-not', 'marker', 'none', '-and', 'LineStyle', 'none');

ntext = numel(findobj(hleg, 'type', 'text'));

IsVisibleOn = strcmp(get(hleg, 'Visible'), 'on');

oldaxunits = get(ax, 'Units');
set([hleg ax], 'Units', 'points')
legpos = get(hleg, 'Position');
axpos = get(ax, 'Position');
set(ax, 'Units', oldaxunits)
legorg = legpos(1:2) + 0.5*legpos(3:4);
axorg = axpos(1:2) + 0.5*axpos(3:4);
invasprat = legpos(3)/legpos(4);
IsVertical = strcmp(get(hleg, 'Orientation'), 'vertical');
legleadx = legorg(1) - axorg(1);
legleady = legorg(2) - axorg(2);

resolution = 10; % in points
IsRight = legleadx > resolution;
IsLeft = legleadx < -resolution;
IsTop = legleady > resolution;
IsBottom = legleady < -resolution;

leftedge = legpos(1);
bottomedge = legpos(2);
rightedge = legpos(1) + legpos(3);
topedge = legpos(2) + legpos(4);

if ~isempty(hmarker) && numel(hmarker)==ntext
    
    childs = get(hleg(1),'Children');
    hmarker = childs(1:3:end);
    hline = childs(2:3:end);
    htext = childs(3:3:end);
    
    for i=1:ntext
        xdata = get(hline(i), 'xdata');
        dx = 0.5*(xdata(2) - xdata(1));
        set(hline(i), 'xdata', xdata - [0 dx])
        xmarker = get(hmarker(i),'xdata');
        set(hmarker(i), 'xdata', xmarker - 0.5*dx)
        textpos = get(htext(i), 'Position');
        set(htext(i), 'Position', textpos-[dx 0 0])
    end
    
    if IsVisibleOn
        repositionlegend(dx)
    end
    
end

% if exist('sfx', 'var')
repositionlegend(sfx)
% end

if exist('sfy', 'var')
    legpos(4) = legpos(4) - sfy*legpos(4);
    if IsTop
        legpos(2) = topedge - legpos(4);
    elseif IsBottom
        legpos(2) = bottomedge;
    else
        legpos(2) = legorg(2) - 0.5*legpos(4);
    end
end

set(hleg, 'Position', legpos);

% legendmoveresize(hleg)
% set(hleg, 'Selected', 'off')
% if ~IsVisibleOn
%     set(hleg, 'box', 'off')
% end

    function repositionlegend(shift)
        legpos(3) = legpos(3) - shift*legpos(3);
        if IsRight
            legpos(1) = rightedge - legpos(3);
        elseif IsLeft
            legpos(1) = leftedge;
        else
            legpos(1) = legorg(1) - 0.5*legpos(3);
        end
        if IsVertical
            legpos(4) = legpos(4) - shift*invasprat*legpos(4);
            if IsTop
                legpos(2) = topedge - legpos(4);
            elseif IsBottom
                legpos(2) = bottomedge;
            else
                legpos(2) = legorg(2) - 0.5*legpos(4);
            end
        end
    end

% function legendmoveresize(hleg)
% set(hleg, 'Visible', 'on', 'box', 'on', 'Selected', 'on', ...
%     'Units', 'points', 'ButtonDownFcn', 'selectmoveresize')
% disp('=== Move/Resize Legend and then press any key to continue:')
% figure(get(hleg, 'Parent'))
% pause

end