
clear all; clc; close all;

fname = 'genereg_stoch_';

n0 = 10;

% [k1,k2,k3] = deal(0.2,20,0.2);
[k1,k2,k3] = deal(2,20,0.2);

casenum = 3;

switch casenum
    case 1
        fname = [fname 'none'];
        k1 = 10*k1;        
    case 2
        fname = [fname 'transcription'];
    case 3
        fname = [fname 'translation'];
        k2 = 5*k2;
    case 4
        fname = [fname 'feedback'];
        k2 = 5*k2;
        k3 = 2*k3;
end

Mobj = sbiomodel('Gene-Regulation Model');
compObj = addcompartment(Mobj, 'contents', 1);
% set(compObj, 'CapacityUnits', 'liter');

Robj1 = addreaction(Mobj, 'G -> G + M');
Kobj1 = addkineticlaw(Robj1,'MassAction');
Pobj1 = addparameter(Kobj1, 'k1', k1);
set(Kobj1, 'ParameterVariableNames', 'k1');
Pobj1.ValueUnits = '1/second';

Robj2 = addreaction(Mobj, 'M -> M + P');
Kobj2 = addkineticlaw(Robj2,'MassAction');
Pobj2 = addparameter(Kobj2, 'k2', k2);
set(Kobj2, 'ParameterVariableNames','k2');
Pobj2.ValueUnits = '1/second';

Robj3 = addreaction(Mobj, 'G + P <-> GP');
Kobj3 = addkineticlaw(Robj3,'MassAction');
Pobj3 = addparameter(Kobj3, 'k3', k3);
Pobj3r = addparameter(Kobj3, 'k3r', 1.0);
set(Kobj3, 'ParameterVariableNames', {'k3', 'k3r'});
Pobj3.ValueUnits = '1/(second*molecule)';
% Pobj3.ValueUnits = '1/(second*molarity)';
Pobj3r.ValueUnits = '1/second';

Robj4 = addreaction(Mobj, 'M -> null');
Kobj4 = addkineticlaw(Robj4, 'MassAction');
Pobj4 = addparameter(Kobj4,  'k4', 1.5);
set(Kobj4, 'ParameterVariableNames','k4');
Pobj4.ValueUnits = '1/second';

Robj5 = addreaction(Mobj, 'P -> null');
Kobj5 = addkineticlaw(Robj5,'MassAction');
Pobj5 = addparameter(Kobj5,  'k5', 1.0);
set(Kobj5, 'ParameterVariableNames','k5');
Pobj5.ValueUnits = '1/second';

Sobj = sbioselect(Mobj, 'Type', 'species');
set(Sobj, 'InitialAmountUnits', 'molecule');
% set(Sobj, 'InitialAmountUnits', 'molarity');
Sobj1 = sbioselect(Sobj, 'Name', 'G');
set(Sobj1, 'InitialAmount', n0);
% set(Sobj1, 'InitialAmount', 5);

cs = getconfigset(Mobj);
set(cs, 'StopTime', 8.0);

[t_ode, x_ode, names] = sbiosimulate(Mobj, cs);
x_ode = x_ode(:,3);

set(cs, 'SolverType', 'ssa');
% cs.SolverOptions.LogDecimation = 10;
cs.SolverOptions.RandomState = [];

[t_ssa, x_ssa] = sbiosimulate(Mobj, cs);
x_ssa = x_ssa(:,3);

runs = 1e3;
cs.SolverOptions.RandomState = [];
simDataObj = sbioensemblerun(Mobj, runs);
[t_ensem,mu,var] = sbioensemblestats(simDataObj, {'P'});
sd = sqrt(var);
newsimDataObj = resample(simDataObj, 1.5, 'zoh');
% [~,nncell] = select(newsimDataObj, {'Type','species','Name','P'});
[~,nncell] = selectbyname(newsimDataObj, 'P');
nn = [nncell{:}]';
[nOut,xbin]=hist(nn,30);
save(fname, 't_ode', 'x_ode', 't_ssa', 'x_ssa', 't_ensem', 'mu', 'sd', 'nOut', 'xbin')