clear all; clc; close all;

Mobj = sbiomodel('cell');
compObj = addcompartment(Mobj, 'contents');
Robj1 = addreaction(Mobj, 'X1 + X2 -> X3');
Kobj1 = addkineticlaw(Robj1,'MassAction');
Pobj1 = addparameter(Kobj1, 'k1', 1.0);
set(Kobj1, 'ParameterVariableNames', 'k1');

Robj1r = addreaction(Mobj, 'X3 -> X1 + X2');
Kobj1r = addkineticlaw(Robj1r,'MassAction');
Pobj1r = addparameter(Kobj1r, 'k1r', 1.0);
set(Kobj1r, 'ParameterVariableNames', 'k1r');

% QObj1 = addparameter(Mobj, 'q1', 30);
% QObj2 = addparameter(Mobj, 'q2', 30);
% ruleObj1 = addrule(Mobj, 'X1+X3-q1');
% ruleObj2 = addrule(Mobj, 'X2+X3-q2');

Sobj1 = sbioselect('Type', 'species', 'Name', 'X1');
set(Sobj1, 'InitialAmount', 15);
Sobj2 = sbioselect('Type', 'species', 'Name', 'X2');
set(Sobj2, 'InitialAmount', 15);
Sobj3 = sbioselect('Type', 'species', 'Name', 'X3');
set(Sobj3, 'InitialAmount', 15);

cs = getconfigset(Mobj);
set(cs, 'StopTime', 1.5);

[t_ode, x_ode] = sbiosimulate(Mobj, cs);
x_ode = x_ode(:,3);

set(cs, 'SolverType', 'ssa');
% cs.SolverOptions.LogDecimation = 10;
cs.SolverOptions.RandomState = [];

[t_ssa, x_ssa] = sbiosimulate(Mobj, cs);
x_ssa = x_ssa(:,3);

runs = 1e3;
cs.SolverOptions.RandomState = [];
simDataObj = sbioensemblerun(Mobj, runs, 'linear');

[t_ensem,mu,var] = sbioensemblestats(simDataObj, {'X3'});
sd = sqrt(var);
newsimDataObj = resample(simDataObj, t_ensem(end), 'zoh');
% [ttcell nncell] = select(newsimDataObj, {'Type','species','Name','X3'});
[ttcell nncell] = selectbyname(newsimDataObj, 'X3');
x_endpoint = [nncell{:}]';

% [nOut,xbin]=hist(x_endpoint,10);


save heterodim_stoch t_ode x_ode t_ssa x_ssa t_ensem mu sd x_endpoint
