clear all;clc;close all

nT = 10;
c = [2 1 3 1.5; 2 3 1 2.5];

param.ntot = nT;


t0 = 0;
tf = 5; % sec
y0 = [nT;0];

t = cell(1,4);
mu = t;
sd = t;
cv = t;

for j=1:4
    param.k = c(:,j);
    [S,a] = makereaction('isom', param);
    dydt = make2ma(S,a);
    [t{j},y] = ode45(dydt, [t0 tf], y0);
    mu{j} = y(:,1);
    sd{j} = sqrt(y(:,2));
    cv{j} = sd{j}./mu{j};
end

Interpreter = 'latex';

%%

% mu = @(t) nT*(c(2,:)+c(1,:).*exp(-(c(1,:)+c(2,:)).*t))./(c(1,:)+c(2,:));
% vmr = @(t) (1-exp(-(c(1,:)+c(2,:)).*t)).*c(1,:)./(c(1,:)+c(2,:));
% sd = @(t) sqrt(mu(t).*vmr(t));
% 
% [T1,Y1] = fplot(@(t) [mu(t)-sd(t), mu(t), mu(t)+sd(t)], [0 5]);
% [T2,Y2] = fplot(@(t) [sd(t), sd(t)./mu(t)], [0 5]);

%%

numax_y = 2;
numax_x = 2;

fig = prepfigure([11.75 8], 'Name', 'isom_band');

dx = .02;
dy = .08;
numax = numax_x*numax_y;

[ax,sax] = prepsubaxes(numax_y,numax_x,[dx dy], [0.08 0.10 0.02 0.06]);

for i=numax:-1:1
    set(fig, 'CurrentAxes', ax(i))
    hold all;
    plot(t{i},mu{i}, '-b')
    
    ti = linspace(0,5,20).';
    yi = interp1q(t{i}, [mu{i},sd{i}], ti);
    errorbar(ti,yi(:,1),yi(:,2), '.b'); 

    htit(i) = title(['$k_w=',num2str(c(1,i)), ...
                      ', k_u=',num2str(c(2,i)), '$']);  
    hold off
end

set(ax, 'xlim', [0 5], 'ylim', [0 10.5])

clear hLine
sax.finish()
set(sax.labelx, 'XTick', [0 2 4]);
set(sax.labely, 'YTick', [0 5 10]);

sax.xlabel('time (sec)')
sax.ylabel('copy number')

set(htit, 'Interpreter', Interpreter)
%%
setfigure
printfigure
%%

fig = prepfigure([11.6 5.5], 'Name', 'isom_std_cv');

pos0 = get(0, 'DefaultAxesPosition');
pos0([1 3]) = pos0([1 3]) + 0.04*[-1 1.5];
pos0(2) = pos0(2) + 0.05;

dx = 0.03;
wd = 0.5*(pos0(3) - dx);

pos = pos0([1 1],:);

pos(:,3) = wd;
pos(2,1) = pos(1,1) + wd + dx;

ax(1) = prepaxes('Position', pos(1,:), 'Box', 'on');
ax(2) = prepaxes('Position', pos(2,:), 'Box', 'on');

set(fig, 'CurrentAxes', ax(1))
for j=4:-1:1
    hLine(j) = line(t{j},sd{j});
end

lineprops = { {'Color'}, {'b';'r';'m';'k'}, ...
              {'LineWidth'}, {1;1.2;1.2;1.2}, ...
              {'LineStyle'}, {'-';'-.';'--';':'} };

axis([0 4 0 1.7])
set(hLine, lineprops{:})
xlabel('time (sec)')
ylabel('SD')

set(fig, 'CurrentAxes', ax(2))
for j=4:-1:1
    hLine(j) = line(t{j},cv{j});
end

axis([0 4 0 0.6])
set(hLine, lineprops{:})
set(ax, 'XTick', [0 2 4]);
set(ax(1), 'YTick', [0 .5 1 1.5]);
set(ax(2), 'YTick', [0 .2 .4 .6], 'YAxisLocation', 'right');
xlabel('time (sec)')
ylabel('CV')

ax0 = axes('visible', 'off', 'Position', pos0);

legstr = @(i) ['$${k_w=', num2str(c(1,i)), ...
                    ' \atop k_u=', num2str(c(2,i)), '}$$'];              
hleg = legend(ax0, hLine, {legstr(1),legstr(2),legstr(3),legstr(4)}, ...
              'Orientation', 'horizontal', ...
              'Color', 'none', 'Location', 'North', 'Interpreter', Interpreter);   
legpos = get(hleg, 'Position');
legpos(2) = 1 - legpos(4);
set(hleg, 'Position', legpos)

pos(:,4) = legpos(2) - pos(:,2) + 0.1*legpos(4);
set(ax(1), 'Position', pos(1,:))
set(ax(2), 'Position', pos(2,:))
fixlegend(hleg, 0.8, 0.8)


%%
setfigure
printfigure
