clear all; close all; clc

k = [1,0.005,0.6];

dndt = @(t,n) [k(1)-k(2)*n(2); k(2)*n(1)-k(3)].*n ;


% Define initial conditions.
t0 = 0;
tf = 30;
n0 = [50;100];
% Simulate the differential equation.
% tf = tf*(1+eps);
options = odeset('Refine',10);
[t,n] = ode45(dndt,[t0 tf],n0, options);

i1 = find(t<15, 1, 'last');
i2 = find(t>5.2, 1, 'first');

%%


figw = 11.8;
figh = 5.2;
aspratio = figh/figw;

prepfigure([figw figh], 'Name', 'lv_ode');

pos0 = get(0, 'DefaultAxesPosition');
pos0([1 3]) = pos0([1 3]) + 0.04*[-1 3];
pos0(2) = pos0(2) + 0.07;

dx = 0.12;
hg = pos0(4);
pos = pos0([1 1],:);

pos(2,3) = aspratio*hg;
pos(1,3) = pos0(3) - aspratio*hg - dx;
pos(2,1) = pos(1,1) + pos(1,3) + dx;

prepaxes('Position', pos(1,:), 'Box', 'on')
hold all;

nmax = max(n(:));
hTimeCourse = plot(t, n);
ylim([0 1.05*nmax])

set(hTimeCourse, {'Color'},{'b';'r'})
htext(1) = text(t(i1),n(i1,1),'prey ');
htext(2) = text(t(i2),n(i2,2),' predator');
set(htext, {'HorizontalAlignment'}, {'right';'left'}, {'Color'}, {'b';'r'})
xlabel('time')
ylabel('population')


prepaxes('Position', pos(2,:), 'Box', 'on')
hold all;

hPhasePlot = line(n(:,1),n(:,2));
ylim([0 1.05*nmax])
xlim([0 1.05*max(n(:,1))])
set(hPhasePlot, 'LineWidth',1,'Color','k')
xlabel('prey population')
ylabel('predator population')

%%
setfigure
printfigure