clear all; clc; close all;

figw = 11.8;
figh = 5.2;
aspratio = figh/figw;

prepfigure([figw figh], 'Name', 'lv_stoch');

pos0 = get(0, 'DefaultAxesPosition');
pos0([1 3]) = pos0([1 3]) + 0.04*[-1 3];
pos0(2) = pos0(2) + 0.07;

dx = 0.12;
hg = pos0(4);
pos = pos0([1 1],:);

pos(2,3) = aspratio*hg;
pos(1,3) = pos0(3) - aspratio*hg - dx;
pos(2,1) = pos(1,1) + pos(1,3) + dx;

prepaxes('Position', pos(1,:), 'Box', 'on')
hold all;
%---------------------------------------------------


load lv_stoch_50x100
t = t_ssa;
n = n_ssa;
i1 = find(t<7.5, 1, 'last');
i2 = find(t>6, 1, 'first');

hTimeCourse = plot(t, n);
% axis tight
nmax = max(n(:));
ylim([0 1.05*nmax])
set(gca, 'YTick', 0:100:nmax)
set(hTimeCourse, {'Color'},{'b';'r'})
htext(1) = text(t(i1),n(i1,1),'prey   ');
htext(2) = text(t(i2),n(i2,2),'   predator');
set(htext, {'HorizontalAlignment'}, {'right';'left'}, {'Color'}, {'b';'r'})
xlabel('time')
ylabel('population')
%---------------------------------------------------

prepaxes('Position', pos(2,:), 'Box', 'on')
hold all;
%---------------------------------------------------

hPhasePlot = line(n(:,1),n(:,2));
ylim([0 1.05*nmax])
xlim([0 1.05*max(n(:,1))])
set(gca, 'YTick', 0:100:nmax)
set(hPhasePlot, 'LineWidth',1,'Color','k')
xlabel('prey population')
ylabel('predator population')

%%
setfigure
printfigure

%%
clear all; clc; close all;
numax_y = 2;
numax_x = 3;
numax = numax_y*numax_x;

fig = prepfigure([11.75 8], 'Name', 'lv_extinction');

dx = .03;
dy = .1;

[ax,sax] = prepsubaxes(numax_y,numax_x,[dx dy], [0.08 0.10 0.01 0.07]);

xinit = zeros(numax_x,numax_y);
xinit(:) = 2.^(3:8);
xinit = xinit.';
yinit = 2*xinit;

nmax = zeros(numax_y, numax_x);

for i=numax:-1:1    
    set(fig, 'CurrentAxes', ax(i))
    N1str = num2str(xinit(i));
    N2str = num2str(yinit(i));
    hold all;
    load(['lv_stoch_',N1str, 'x', N2str])
    t = t_ssa;
    n = n_ssa;
    hLine(i,:) = plot(t,n);
    htit(i) = title(['$N_1(0)=', N1str, ', N_2(0)=', N2str, '$']);
    nmax(i) = max(n(:));
    axis square
    hold off    
end

set(hLine(2,:), 'LineStyle', '--', 'LineWidth', 1.2, 'Color', 'r')

ylimmax = max(nmax, [], 2);

set(ax(1,:), 'XTick', [], 'YLim', [0 1.05*ylimmax(1)]);
set(ax(2,:), 'XTick', 0:10:30, 'YLim', [0 1.05*ylimmax(2)]);
set(ax(:,2:end), 'YTick', []);
set(ax(1), 'YTick', 0:400:ylimmax(1));
set(ax(2), 'YTick', 0:200:ylimmax(2));

for a=ax(2,:)
    xlabel(a, 'time (sec)')
end

for a=ax(:,1).'
    ylabel(a, 'population')
end

set(htit, 'Interpreter', 'latex')
%%
setfigure
printfigure
