function [S, a] = makereaction(modelname, param)

ssz = 1;

if isfield(param, 'ssz')
    ssz = param.ssz;
end

invssz = 1/ssz;
k = param.k;

switch lower(modelname)
    case 'isom'
        ntot = param.ntot;        
        S = [-1 1];
        a = @(n) [ k(1)*n ; k(2)*(ntot-n) ] ;        
    case 'heterodim'
        q = param.q;
        S = [1 -1];
        a = @(n) [ k(1)*(q(1)-n)*(q(2)-n) ; k(2)*n ] ;        
    case 'lv'        
        S = [ 1  -1   0
              0   1  -1 ];
        a = @(n) [ k(1)*n(1) ; k(2)*n(1)*n(2) ; k(3)*n(2) ] ;
    case 'enzkin'
        etot = param.etot;
        S = [ -1   1   0
               1  -1  -1 ];
        a = @(n) [ k(1)*n(1)*(etot - n(2)) ; k(2)*n(2) ; k(3)*n(2) ] ;        
    case 'sf'
        S = [ 1  -1  0   0
              0   0  1  -1 ];
        a = @(n) [ k(1) ; k(2)*n(1) ; k(3)/(1+n(1)/k(4)) ; n(2) ] ;        
    case 'schloegl'
        xA = param.xA;
        xB = param.xB;
        k(1:3) = k(1:3).*[xA*invssz invssz.^2 xB*ssz];
        S = [1 -1];
        a = @(n) [ k(1)*n*(n-1)+k(3) ; (k(2)*(n-1)*(n-2)+k(4))*n ] ;
    case 'genereg'
        nGtot = param.nGtot;
        S = [ 0  0 -1  1  0  0
              1  0  0  0 -1  0
              0  1 -1  1  0 -1 ] ;
        a = @(n) k.*[n(1) ; n(2) ; n(1)*n(3) ; nGtot-n(1) ; n(2) ; n(3)];
    otherwise
        error('Unsupported model')
end


end
     