function hAx = prepaxes(varargin)
%PREPAXES   prepares axes for plotting
%
%   PREPAXES creates a new axes sets its 'FontSize' to 8, 'LineWidth' to 0.4,
%   'Box' to 'off', 'TickDir' to 'out' and 'Color' to 'none'.
%
%
%   PREPAXES(B) chooses the axes position so that its margins left, right,
%   bottom and top are given by the vector B.
%
%
%   PREPAXES(..., 'PROP1', 'VAL1', 'PROP2', 'VAL2', ...) also sets the 
%   specified properties of the axes.
%   
%
%   PREPAXES(AX, ...) prepares axes with handle AX instead of creating a
%   new one.
%   
%

% Mukhtar Ullah
% mukhtar.ullah@informatik.uni-rostock.de
% Created: Feb 5, 2008
% Last modified: Oct 14, 2010

[ax, args] = axescheck(varargin{:});

if isempty(ax)
	ax = axes();
else
    set(get(ax, 'Parent'), 'CurrentAxes', ax)
end

if ~isempty(args) && isnumeric(args{1})
    b = args{1};
    validateattributes(b, {'numeric'}, {'vector','nonnegative', '<', 1})    
    switch numel(b)        
        case 1
            axpos = [b b 1-b 1-b];
        case 2
            axpos = [b(1:2) 1-b(1:2)];
        case 4
            axpos = [b(1) b(2) 1-b(1)-b(3) 1-b(2)-b(4)];
        otherwise
            error('The margin B must be a 1-, 2- or 4-element vector')
    end
    set(ax, 'Position', axpos)
    args = args(2:end);
end

set(ax, 'FontSize', 8, ...
        'LineWidth', 0.4, ...
        'Color', 'none',  args{:} )
    
% Use hold all with caution. It creates a problem when using logarithmic
% scaling

% hold all

if nargout==1
    hAx = ax;
end
