function [axOut,sax] = prepsubaxes(varargin)

p = inputParser;

p.addRequired('rows', @(x) isscalar(x) && x>0);
p.addRequired('columns', @(x) isscalar(x) && x>0);
p.addOptional('gape', .05, @(x) numel(x)<3);
p.addOptional('margin', [], @isvector);
p.addParamValue('xscaling', [], @isvector);
p.addParamValue('yscaling', [], @isvector);

p.parse(varargin{:});
m = floor(p.Results.rows);
n = floor(p.Results.columns);
d = p.Results.gape;
b = p.Results.margin;
sx = p.Results.xscaling;
sy = p.Results.yscaling;

validateattributes(d, {'numeric'}, {'nonnegative', '<', 1})

switch numel(d)    
    case 0
        dx = 0.05;
        dy = 0.05;
    case 1
        dx = d;
        dy = d;
    case 2
        dx = d(1);
        dy = d(2);
end

validateattributes(b, {'numeric'}, {'nonnegative', '<', 1})

switch numel(b)
    case 0
        pos0 = get(0, 'DefaultAxesPosition');
    case 1
        pos0 = [b b 1-b 1-b];
    case 2
        pos0 = [b(1:2) 1-b(1:2)];
    case 4
        pos0 = [b(1) b(2) 1-b(1)-b(3) 1-b(2)-b(4)];
    otherwise
        error('The margin B must be a 1-, 2- or 4-element vector')
end

if isempty(sx)
    sx = ones(1,n);
else
    assert(numel(sx)==n, 'SX must be N-element vector')
end

if isempty(sy)
    sy = ones(m,1);
else 
    assert(numel(sy)==m, 'SY must be M-element vector')
end

wd = sx*(pos0(3) - (n-1)*dx)/sum(sx);
hg = sy(:)*(pos0(4) - (m-1)*dy)/sum(sy);
pos0(2) = pos0(2) + (m-1)*dy + sum(hg(2:m));

pos = repmat(reshape(pos0,1,1,[]), m, n);

pos(:,:,3) = repmat(wd, m, 1);
pos(:,:,4) = repmat(hg, 1, n);

for i=2:m
    pos(i,:,2) = pos(i-1,:,2) - pos(i,:,4) - dy;
end

for j=2:n
    pos(:,j,1) = pos(:,j-1,1) + pos(:,j-1,3) + dx;
end

ax = zeros(m,n);

for i=1:m
    for j=1:n
        ax(i,j) = axes('Color', 'none', 'Box', 'on', 'Position', pos(i,j,:));
    end
end

if nargout>0
    axOut = ax;
end

if nargout>1
%     sax.base = pos0;
%     sax.position = pos;    
    if n<3
        sax.labelx = ax(end,:);
        sax.nolabelx = ax(1:end-1,:);
        sax.xxtop = [];
    else
        sax.labelx = [ax(end,1:2:end) ax(1,2:2:end)]';
        nolabx1 = ax(1:end-1,1:2:end);
        nolabx2 = ax(2:end,2:2:end);
        sax.nolabelx = [nolabx1(:);nolabx2(:)];
        sax.xxtop = ax(1,2:2:end);
    end
    if m<3
        sax.labely = ax(:,1);
        sax.nolabely = ax(:,2:end);
        sax.yyright = [];
    else
        sax.labely = [ax(1:2:end,1) ax(2:2:end,end)]';
        nolaby1 = ax(1:2:end,2:end);
        nolaby2 = ax(2:2:end,1:end-1);
        sax.nolabely = [nolaby1(:);nolaby2(:)];
        sax.yyright = ax(2:2:end,end);
    end
    sax.finish = @finishit;
    sax.xlabel = @xlabelit;
    sax.ylabel = @ylabelit;
    sax.zlabel = @zlabelit;
end

    function finishit()
        set(sax.nolabelx, 'XTick', []);
        set(sax.nolabely, 'YTick', []);
        set(sax.xxtop, 'XAxisLocation', 'top');
        set(sax.yyright, 'YAxisLocation', 'right');
    end

    function hOut = xlabelit(str, varargin)
        h = get(sax.labelx, 'XLabel');
        if iscell(h)
            h = [h{:}];
        end
        set(h, 'String', str, varargin{:})
        if nargout>0
            hOut = h;
        end
    end

    function hOut = ylabelit(str,varargin)
        h = get(sax.labely, 'YLabel');
        if iscell(h)
            h = [h{:}];
        end
        set(h, 'String', str, varargin{:})
        if nargout>0
            hOut = h;
        end
    end

    function hOut = zlabelit(str,varargin)
        h = get(sax.labely, 'ZLabel');
        if iscell(h)
            h = [h{:}];
        end
        set(h, 'String', str, varargin{:})
        if nargout>0
            hOut = h;
        end
    end

end

