clear all; clc; close all;

model = sbiomodel('Schloegl Model');

% Enter Reactions

r1 = addreaction(model,'2 x <-> 3 x');
r2 = addreaction(model, 'null <-> x');

% Set the Kinetic Law for Reactions

kl1 = addkineticlaw(r1, 'MassAction');
kl2 = addkineticlaw(r2, 'MassAction');

% Add rate constants for each reaction

ninit = 100;
[V,xa,xb] = deal(80,1,2);
[k1,k2,k3,k4] = deal(3.0,0.6,0.25,2.95);

k1hat = k1*xa/V;
k2hat = k2/V^2;
k3hat = k3*xb*V;

p1f = addparameter(kl1, 'k1hat', 'Value', k1hat);
p1r = addparameter(kl1, 'k2hat', 'Value', k2hat);
p2f = addparameter(kl2, 'k3hat', 'Value', k3hat);
p2r = addparameter(kl2, 'k4', 'Value', k4);

kl1.ParameterVariableNames = {'k1hat', 'k2hat'};
kl2.ParameterVariableNames = {'k3hat', 'k4'};

% Set initial amounts for species
model.species.InitialAmount = ninit;    % x

cs = getconfigset(model);
set(cs, 'StopTime', 5);
[t_ode, x_ode] = sbiosimulate(model, cs);


set(cs, 'SolverType', 'ssa');
set(cs.SolverOptions, 'LogDecimation', 10, 'RandomState', []);
% cs.SolverOptions.RandomState = [];

runs = 5;
simDataObj = sbioensemblerun(model, runs);
[tcell, ncell] = select(simDataObj, {'Type','species'});
save(['schloegl_traj_init', num2str(ninit)], 't_ode', 'x_ode', 'tcell', 'ncell')

%%
runs = 1e4;

set(cs, 'StopTime', 6);
cs.SolverOptions.RandomState = [];
simDataObj = sbioensemblerun(model, runs);


%%
load schlog_ensem_sim;
simdata = getdata(simDataObj);

t = simdata.Time;

[ttcell, nncell] = select(simDataObj, {'Type','species'});

% tlast = min(cellfun(@(x) x(end), ttcell));
% tfirst = min(cellfun(@(x) x(2), ttcell));

% ts = zeros(20,4);
% ts(:,1) = linspace(0,0.009,20); 
% ts(:,2) = linspace(0.01,0.09,20);
% ts(:,3) = linspace(0.1,0.9,20);
% ts(:,4) = linspace(1,5,20);

ts = zeros(20,2);
ts(:,1) = linspace(0,0.9,20);
ts(:,2) = linspace(1,5,20);


newsimDataObj = resample(simDataObj, ts(:), 'zoh');

[~, nscell] = select(newsimDataObj, {'Type','species'});

ns = cell2mat(nscell')';
% save schloegl_ensem_selected ts ns